==> huaweicloudsdkcts-3.1.116-py2.py3-none-any.whl: huaweicloudsdkcts/v3/model/check_obs_buckets_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CheckObsBucketsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'domain_id': 'str',
        'body': 'CheckObsBucketsRequestBody'
    }

    attribute_map = {
        'domain_id': 'domain_id',
        'body': 'body'
    }

    def __init__(self, domain_id=None, body=None):
        """CheckObsBucketsRequest

        The model defined in huaweicloud sdk

        :param domain_id: 账户id，参见《云审计服务API参考》“获取账号ID和项目ID”章节。
        :type domain_id: str
        :param body: Body of the CheckObsBucketsRequest
        :type body: :class:`huaweicloudsdkcts.v3.CheckObsBucketsRequestBody`
        """
        
        

        self._domain_id = None
        self._body = None
        self.discriminator = None

        self.domain_id = domain_id
        if body is not None:
            self.body = body

    @property
    def domain_id(self):
        """Gets the domain_id of this CheckObsBucketsRequest.

        账户id，参见《云审计服务API参考》“获取账号ID和项目ID”章节。

        :return: The domain_id of this CheckObsBucketsRequest.
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this CheckObsBucketsRequest.

        账户id，参见《云审计服务API参考》“获取账号ID和项目ID”章节。

        :param domain_id: The domain_id of this CheckObsBucketsRequest.
        :type domain_id: str
        """
        self._domain_id = domain_id

    @property
    def body(self):
        """Gets the body of this CheckObsBucketsRequest.

        :return: The body of this CheckObsBucketsRequest.
        :rtype: :class:`huaweicloudsdkcts.v3.CheckObsBucketsRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this CheckObsBucketsRequest.

        :param body: The body of this CheckObsBucketsRequest.
        :type body: :class:`huaweicloudsdkcts.v3.CheckObsBucketsRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckObsBucketsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcts-3.1.155-py2.py3-none-any.whl: huaweicloudsdkcts/v3/model/check_obs_buckets_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CheckObsBucketsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'domain_id': 'str',
        'body': 'CheckObsBucketsRequestBody'
    }

    attribute_map = {
        'domain_id': 'domain_id',
        'body': 'body'
    }

    def __init__(self, domain_id=None, body=None):
        r"""CheckObsBucketsRequest

        The model defined in huaweicloud sdk

        :param domain_id: 账户id，参见《云审计服务API参考》“获取账号ID和项目ID”章节。
        :type domain_id: str
        :param body: Body of the CheckObsBucketsRequest
        :type body: :class:`huaweicloudsdkcts.v3.CheckObsBucketsRequestBody`
        """
        
        

        self._domain_id = None
        self._body = None
        self.discriminator = None

        self.domain_id = domain_id
        if body is not None:
            self.body = body

    @property
    def domain_id(self):
        r"""Gets the domain_id of this CheckObsBucketsRequest.

        账户id，参见《云审计服务API参考》“获取账号ID和项目ID”章节。

        :return: The domain_id of this CheckObsBucketsRequest.
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        r"""Sets the domain_id of this CheckObsBucketsRequest.

        账户id，参见《云审计服务API参考》“获取账号ID和项目ID”章节。

        :param domain_id: The domain_id of this CheckObsBucketsRequest.
        :type domain_id: str
        """
        self._domain_id = domain_id

    @property
    def body(self):
        r"""Gets the body of this CheckObsBucketsRequest.

        :return: The body of this CheckObsBucketsRequest.
        :rtype: :class:`huaweicloudsdkcts.v3.CheckObsBucketsRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this CheckObsBucketsRequest.

        :param body: The body of this CheckObsBucketsRequest.
        :type body: :class:`huaweicloudsdkcts.v3.CheckObsBucketsRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckObsBucketsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
